@@ -16,6 +16,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with PyCha.  If not, see <http://www.gnu.org/licenses/>.
 
+import six
+
+str = six.text_type
+
+
 def clamp(minValue, maxValue, value):
     """Make sure value is between minValue and maxValue"""
     if value < minValue:
@@ -27,13 +32,13 @@ def clamp(minValue, maxValue, value):
 
 def safe_unicode(obj, encoding=None):
     """Return a unicode value from the argument"""
-    if isinstance(obj, unicode):
+    if isinstance(obj, str):
         return obj
     elif isinstance(obj, str):
         if encoding is None:
-            return unicode(obj)
+            return str(obj)
         else:
-            return unicode(obj, encoding)
+            return str(obj, encoding)
     else:
         # it may be an int or a float
-        return unicode(obj)
+        return str(obj)
